##
## rgig.R:
##
## Ester Pantaleo and Robert B. Gramacy, 2010
##
## adapted from the C code in the monomvm package for R, and the
## R code in the fBasics and ghyp packages
##


dyn.load("../src/rgig.so")


## rgig.C:
##
## function to sample from a Generalized Inverse Gaussian
## distribution.  The is an R-wrapper function for a C
## routine modeled after the rgig function in the ghyp
## package

rgig.C <- function(n = 10, lambda = 1, chi = 1, psi = 1)
  {
    ## a tolerance for the sanity checks below
    ZTOL <- .Machine$double.eps
    
    ## both chi and psi must be non-negative
    if((chi < 0) | (psi < 0)) 
      stop("Invalid parameters for GIG")
    
    ## sanity check for chi 
    if((chi < ZTOL) & (lambda <= 0)) 
      stop("Invalid parameters for GIG")
    
    ## sanity check for psi 
    if((psi < ZTOL) & (lambda >= 0))
      stop("Invalid parameters for GIG")
    
    ## call the C routine
    z <- .C("rgig_R",
            n = as.integer(n),
            lambda = as.double(lambda),
            chi = as.double(chi),
            psi = as.double(psi),
            samps = double(n))$samps
    
    ## return the samples
    return(z)
  }
